@@ -27,7 +27,6 @@ import contacts as ContactH
 import logging
 log = logging.getLogger('fmms.%s' % __name__)
 
-
 class fMMS_GUI(hildon.Program):
 
 	def __init__(self):
@@ -36,8 +35,10 @@ class fMMS_GUI(hildon.Program):
 		self._mmsdir = self.config.get_mmsdir()
 		self._pushdir = self.config.get_pushdir()
 		self.ch = ContactH.ContactHandler()
-		self.osso_c = osso.Context("fMMS", self.config.get_version(), False)
+		
+		self.osso_c = osso.Context("se.frals.fmms", self.config.get_version(), False)
 		self.osso_rpc = osso.Rpc(self.osso_c)
+      		self.osso_rpc.set_rpc_callback("se.frals.fmms","/se/frals/fmms","se.frals.fmms", self.cb_open_fmms, self.osso_c)
 		
 		self.refreshlistview = True
 	
@@ -50,11 +51,9 @@ class fMMS_GUI(hildon.Program):
 	
 		hildon.Program.__init__(self)
 		program = hildon.Program.get_instance()
-		
-		self.osso_rpc = osso.Rpc(self.osso_c)
-      		self.osso_rpc.set_rpc_callback("se.frals.fmms","/se/frals/fmms","se.frals.fmms", self.cb_open_fmms, self.osso_c)
-		
+			
 		self.window = hildon.StackableWindow()
+		gtk.set_application_name("fMMS")
 		self.window.set_title("fMMS")
 		program.add_window(self.window)
 		
@@ -138,6 +137,18 @@ class fMMS_GUI(hildon.Program):
 		
 		self.window.show_all()
 		self.add_window(self.window)
+		
+		self._expose_event = self.window.connect('expose-event', self.take_ss)
+
+	""" for taking a screenshot of the app to fake superfast load
+	    ... just need it to actually include the listview now ...
+	
+	    inspired by Andrew Flegg and WimpWorks 
+	    @see http://maemo.org/api_refs/5.0/5.0-final/hildon/hildon-Additions-to-GTK+.html#hildon-gtk-window-take-screenshot """
+     	def take_ss(self, event=None, data=None):
+		self.window.disconnect(self._expose_event)
+		if not os.path.isfile("/home/user/.cache/launch/se.frals.fmms.pvr"):
+			gobject.timeout_add(2000, hildon.hildon_gtk_window_take_screenshot, self.window, True)
 
 
 	""" need this to always have the current path """
@@ -163,7 +174,7 @@ class fMMS_GUI(hildon.Program):
 			
 			if self.config.get_firstlaunch() == 1:
 						note = osso.SystemNote(self.osso_c)
-						firstlaunchmessage = "NOTE: Currently you have to connect manually to the MMS APN when sending and receiving.\nOnly implemented attachment is image."
+						firstlaunchmessage = "NOTE: Read the thread on talk.maemo.org."
 						note = hildon.hildon_note_new_information(self.window, firstlaunchmessage)
 						self.create_config_dialog()
 						self.config.set_firstlaunch(0)
@@ -284,6 +295,7 @@ class fMMS_GUI(hildon.Program):
 		number_label = gtk.Label("Your phonenumber:")
 		number_label.set_width_chars(labelwidth)
 		self.number = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
+		self.number.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_TELE)
 		number_text = self.config.get_phonenumber()
 		if number_text != None:
 			self.number.set_text(number_text)
@@ -297,7 +309,8 @@ class fMMS_GUI(hildon.Program):
 		imgwidth_label.set_width_chars(labelwidth)
 		self.imgwidth = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
 		self.imgwidth.set_max_length(5)
-		self.imgwidth_signal = self.imgwidth.connect('insert_text', self.insert_resize_cb)
+		#self.imgwidth_signal = self.imgwidth.connect('insert_text', self.insert_resize_cb)
+		self.imgwidth.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
 		imgwidth_text = self.config.get_img_resize_width()
 		if imgwidth_text != None:
 			self.imgwidth.set_text(str(imgwidth_text))
@@ -342,36 +355,6 @@ class fMMS_GUI(hildon.Program):
 		ret2 = self.config_menu_button_clicked(ret)
 		dialog.destroy()
 
-		
-	""" from http://faq.pygtk.org/index.py?req=show&file=faq14.005.htp """
-	def insert_resize_cb(self, widget, text, length, *args):
-		# if you don't do this, garbage comes in with text
-		text = text[:length]
-		pos = widget.get_position()
-		# stop default emission
-		widget.emit_stop_by_name("insert_text")
-		signal = self.imgwidth_signal
-		gobject.idle_add(self.insert_nr_mod, widget, signal, text, pos)
-		
-		
-	""" from http://faq.pygtk.org/index.py?req=show&file=faq14.005.htp """
-	def insert_nr_mod(self, widget, signal, text, pos):
-		# the next three lines set up the text. this is done because we
-		# can't use insert_text(): it always inserts at position zero.
-		orig_text = widget.get_text()
-		#text = string.replace(text, " ", "<SPACE>")
-		pattern = re.compile('[!^\D]')
-		text = pattern.sub("", text)
-		new_text = orig_text[:pos] + text + orig_text[pos:]
-		# avoid recursive calls triggered by set_text
-		widget.handler_block(signal)
-		# replace the text with some new text
-		widget.set_text(new_text)
-		widget.handler_unblock(signal)
-		# set the correct position in the widget
-		widget.set_position(pos + len(text))
-
-
 
 	""" selector for apn """
 	def create_apn_selector(self):
